<?php
/**
 * Add function to widgets_init that'll load our widget.
 */
add_action( 'widgets_init', 'bk_register_widget_categories' );

function bk_register_widget_categories() {
	register_widget( 'bk_widget_categories' );
}

/**
 * This class handles everything that needs to be handled with the widget:
 * the settings, form, display, and update.  Nice!
 *
 */
class bk_widget_categories extends WP_Widget {

	/**
	 * Widget setup.
	 */
	function __construct() {
		/* Widget settings. */
		$widget_ops = array( 'classname' => 'mnmd-widget', 'description' => esc_html__('Displays Categories.', 'rubik') );

		/* Create the widget. */
		parent::__construct( 'bk_widget_categories', esc_html__('BK: Widget Categories', 'rubik'), $widget_ops);
	}
    
	/**
	 *display the widget on the screen.
	 */
	function widget( $args, $instance ) {
		extract( $args );
        
        $widget_opts = array();
        $title       = $instance['title'];
        $categories_info = strip_tags($instance['category_info']);
        $category_orderby = strip_tags($instance['category_orderby']);
        $category_order = strip_tags($instance['category_order']);
        $entries =  strip_tags($instance['entries']);
        echo ($before_widget);
        
        if ( $title ) {?>
            <div class="widget-title-wrap">
                <?php echo $before_title . esc_html($title) . $after_title;?>
            </div>
        <?php }?>
        
        <?php 
            $cat_args = array(
                            'number'    => $entries,
                            'orderby'   => $category_orderby,
                            'order'     => $category_order,
                            'title_li'  => '',
                        );
            $rubik_categories = get_categories($cat_args);
        ?>
        <div class="rubik-widget-categories rubik-widget widget">
            <ul class="list-unstyled">
                <?php foreach($rubik_categories as $rubik_category):?>
                    <li>
                        <a href="<?php echo get_category_link($rubik_category->term_id );?>">
                            <span class="rubik-cat-name"><?php echo $rubik_category->cat_name;?></span>
                            <?php if($categories_info != 'disable') {?>
                                <span class="rubik-cat-count-no"><?php echo $rubik_category->count;?></span>
                            <?php }?>
                        </a>
                    </li>
                <?php endforeach;?>
            </ul>
        </div>
        <?php
        /* After widget (defined by themes). */
		echo ($after_widget);
	}
	
	/**
	 * update widget settings
	 */
	function update($new_instance, $old_instance) {
		$instance = $old_instance;
        $instance['title']          = $new_instance['title'];
        $instance['category_orderby']= strip_tags($new_instance['category_orderby']);
        $instance['category_order'] = strip_tags($new_instance['category_order']);
        $instance['category_info']  = strip_tags($new_instance['category_info']);
        $instance['entries']   = $new_instance['entries'];
		return $instance;
	}

	/**
	 * Displays the widget settings controls on the widget panel.
	 * Make use of the get_field_id() and get_field_name() function
	 * when creating your form elements. This handles the confusing stuff.
	 */
	function form( $instance ) {
		$defaults = array('title' => 'Categories', 'heading_style' => 'default', 'category_order' => 'ASC', 'category_orderby' => 'count', 'category_info' => 'post-count', 'entries' => 5);
		$instance = wp_parse_args((array) $instance, $defaults);
	?>
        <p>
			<label for="<?php echo esc_attr($this->get_field_id( 'title' )); ?>"><strong><?php esc_html_e('[Optional] Title:', 'rubik'); ?></strong></label>
			<input type="text" class="widefat" id="<?php echo esc_attr($this->get_field_id('title')); ?>" name="<?php echo esc_attr($this->get_field_name('title')); ?>" value="<?php if( !empty($instance['title']) ) echo esc_attr($instance['title']); ?>" />
		</p>
        
        <p>
		    <label for="<?php echo esc_attr($this->get_field_id( 'category_orderby' )); ?>"><?php esc_attr_e('[Optional] Categories Order By :', 'rubik'); ?></label>
		    <select class="widefat" id="<?php echo esc_attr($this->get_field_id( 'category_orderby' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'category_orderby' )); ?>" >
                <option value="count" <?php if( !empty($instance['category_orderby']) && $instance['category_orderby'] == 'count' ) echo 'selected="selected"'; else echo ""; ?>><?php esc_attr_e('Post Count', 'rubik'); ?></option>
			    <option value="name" <?php if( !empty($instance['category_orderby']) && $instance['category_orderby'] == 'name' ) echo 'selected="selected"'; else echo ""; ?>><?php esc_attr_e('Name', 'rubik'); ?></option>
			 </select>
	    </p>
        <p>
		    <label for="<?php echo esc_attr($this->get_field_id( 'category_order' )); ?>"><?php esc_attr_e('[Optional] Categories Order By :', 'rubik'); ?></label>
		    <select class="widefat" id="<?php echo esc_attr($this->get_field_id( 'category_order' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'category_order' )); ?>" >
                <option value="ASC" <?php if( !empty($instance['category_order']) && $instance['category_order'] == 'ASC' ) echo 'selected="selected"'; else echo ""; ?>><?php esc_attr_e('ASC', 'rubik'); ?></option>
			    <option value="DESC" <?php if( !empty($instance['category_order']) && $instance['category_order'] == 'DESC' ) echo 'selected="selected"'; else echo ""; ?>><?php esc_attr_e('DESC', 'rubik'); ?></option>
			 </select>
	    </p>
        <p>
		    <label for="<?php echo esc_attr($this->get_field_id( 'category_info' )); ?>"><?php esc_attr_e('[Optional] Categories Info :', 'rubik'); ?></label>
		    <select class="widefat" id="<?php echo esc_attr($this->get_field_id( 'category_info' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'category_info' )); ?>" >
                <option value="post-count" <?php if( !empty($instance['category_info']) && $instance['category_info'] == 'post-count' ) echo 'selected="selected"'; else echo ""; ?>><?php esc_attr_e('Show Post Count', 'rubik'); ?></option>
			    <option value="disable" <?php if( !empty($instance['category_info']) && $instance['category_info'] == 'disable' ) echo 'selected="selected"'; else echo ""; ?>><?php esc_attr_e('Disable', 'rubik'); ?></option>
			 </select>
	    </p>
        
        <p><label for="<?php echo esc_attr($this->get_field_id( 'entries' )); ?>"><strong><?php esc_html_e('[Optional] Number of entries to display: ', 'rubik'); ?></strong></label>
		<input class="widefat" type="text" id="<?php echo esc_attr($this->get_field_id('entries')); ?>" name="<?php echo esc_attr($this->get_field_name('entries')); ?>" value="<?php echo esc_attr($instance['entries']); ?>"/></p>
<?php
	}
}
?>
